class AbstractBaseClass(object):

    def __init__(self, client_sdk):
        self.client_sdk = client_sdk

    def get(self, params=None):
        return self.client_sdk.request("get", params=params)

    



import requests
from ayomide_sdk.api_resources.helpers import build_filters

class ApiRequester:
    def __init__(self, method_type, url, headers, params, filters):
        self.method_type = method_type
        self.url = url
        self.headers = headers
        self.params = params
        self.filters = filters

    def get(self):

        filter_query = "?"

        if self.filters != {} and self.filters != None:
            filter_query = build_filters(self.filters)

        if self.params != None and self.params.get("id", None) != None:
            if self.params.get("subquery", None) == None:
                id = self.params["id"]
                endpoint = self.url + f"/{id}" + filter_query
                response = requests.get(
                    endpoint,
                    headers=self.headers,
                )
            else:
                id = self.params["id"]
                subquery = self.params["subquery"]
                endpoint = self.url + f"/{id}/{subquery}" + filter_query
                response = requests.get(
                    endpoint,
                    headers=self.headers,
                )
        else:
            endpoint = self.url + filter_query
            response = requests.get(
                endpoint,
                headers=self.headers,
            )
        print(endpoint)
        print(self.params)
        print(self.filters)
        return response

    def post():
        return {
            "status_code": 200,
            "json": {"message": "This method is not implemented"},
        }

    def put():
        return {
            "status_code": 200,
            "json": {"message": "This method is not implemented"},
        }

    def delete():
        return {
            "status_code": 200,
            "json": {"message": "This method is not implemented"},
        }



from ayomide_sdk.api_resources.abstract import AbstractBaseClass


class Quote:
    def __init__(self, client_sdk, api_type):
        """
        Initialize the Quote
        """
        self.api_type = api_type
        self.client_sdk = client_sdk

    def get(self, params=None, filters={}):
        return self.client_sdk.request(
            method_type="get", params=params, api_type=self.api_type, filters=filters
        )

    def __repr__(self):
        """
        string representation
        """
        return "<ayomide_sdk.Quote>"




def full_url_query_builder(base_url, api_type):
    return base_url + f"/{api_type}"


def build_filters(filters):
    filter_query = "?"
    for k,v in filters.items():
        filter_query = filter_query + f"{k}={v}&"
    return filter_query[:-1]  #remove trailing &



import os
from ayomide_sdk.api_resources.constants import BASE_URL_V1, BASE_URL_V2
from ayomide_sdk.api_resources.api_requester import ApiRequester
from ayomide_sdk.api_resources.helpers import full_url_query_builder


class Client(object):
    """
    A client for accessing the hedera_mirror API.
    """

    def __init__(self, api_key=None, version=None):
        base_url = BASE_URL_V1 if version.lower() == "v1" else BASE_URL_V2
        if api_key is None:
            raise Exception("Api key is required")

        if version.lower() == "v1":
            raise NotImplementedError(
                "This sdk does not support version v1 , please upgrade to v2"
            )
        try:
            self.base_url = base_url.strip().lower()
        except Exception as e:
            raise Exception(str(e))
        self.headers = {"Authorization": f"Bearer {api_key}"}

    def request(self, method_type, params=None, api_type=None, filters={}):
        method_type = method_type.upper()

        # build full url
        full_url = full_url_query_builder(self.base_url, api_type)

        api_requester = ApiRequester(
            url=full_url,
            method_type=method_type,
            params=params,
            headers=self.headers,
            filters=filters,
        )

        if method_type == "GET":
            response = api_requester.get()
        elif method_type == "PUT":
            response = api_requester.put()
        elif method_type == "POST":
            response = api_requester.post()
        elif method_type == "DELETE":
            response = api_requester.delete()

        json_response = response.json()
        return {"status": response.status_code, "json": json_response}

    @property
    def quote(self):
        """
        Access the did_sdk Account API
        """
        from ayomide_sdk.rest.quote import Quote

        quote_resp = Quote(self, "quote")
        return quote_resp

    @property
    def movie(self):
        """
        Access the did_sdk Account API
        """
        from ayomide_sdk.rest.movie import Movie

        movie_resp = Movie(self, "movie")
        return movie_resp
